==> csbase-client-1.2.0-sources.jar: csbase/client/algorithms/parameters/InputFileListParameterView.java <==
/**
 * $Id: InputFileListParameterView.java 149543 2014-02-11 13:02:45Z oikawa $
 */

package csbase.client.algorithms.parameters;

import java.awt.Window;
import java.text.MessageFormat;
import java.util.HashSet;
import java.util.Set;

import tecgraf.javautils.core.io.FileUtils;
import tecgraf.javautils.gui.StandardDialogs;
import csbase.client.desktop.DesktopFrame;
import csbase.client.kernel.ClientException;
import csbase.client.project.ProjectFileChooser;
import csbase.client.project.ProjectFileChooserOpen;
import csbase.client.project.ProjectTreePath;
import csbase.logic.ClientProjectFile;
import csbase.logic.ProjectFileType;
import csbase.logic.algorithms.FileParameterValue;
import csbase.logic.algorithms.parameters.FileParameterMode;
import csbase.logic.algorithms.parameters.InputFileListParameter;

/**
 * Viso para {@link InputFileListParameter Parmetro do Tipo de Arquivo de
 * Entrada} com Seleo Mltipla.
 * 
 * @author lmoreira
 */
public final class InputFileListParameterView extends FileListParameterView {

  /**
   * Cria uma viso em modo {@link ParameterView.Mode#CONFIGURATION}.
   * 
   * @param window NO EST SENDO UTILIZADO. Existe somente para manter
   *        compatibilidade com o WebSintesi.
   * @param parameter O parmetro (No aceita {@code null}).
   * 
   * @deprecated para manter compatibilidade com o WebSintesi
   */
  @Deprecated
  public InputFileListParameterView(Window window,
    InputFileListParameter parameter) {
    this(parameter, Mode.CONFIGURATION);
  }

  /**
   * Cria uma viso.
   * 
   * @param parameter O parmetro (No aceita {@code null}).
   * @param mode Modo de visualizao. No aceita {@code null}, os possveis
   *        valores so: {@link ParameterView.Mode#CONFIGURATION} ou
   *        {@link ParameterView.Mode#REPORT}.
   */
  public InputFileListParameterView(InputFileListParameter parameter, Mode mode) {
    super(parameter, mode);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public InputFileListParameter getParameter() {
    return (InputFileListParameter) super.getParameter();
  }

  /**
   * Solicita os arquivos ao usurio.
   * 
   * @return O conjunto de arquivos selecionados (Se o usurio cancelar a
   *         seleo, o conjunto estar vazio; se houver um erro durante a
   *         seleo, retorna {@code null}).
   */
  @Override
  protected Set<FileParameterValue> askForFile() {
    try {
      Set<FileParameterValue> files = new HashSet<FileParameterValue>();
      ProjectFileChooser chooser =
        new ProjectFileChooserOpen(getWindow(), DesktopFrame.getInstance()
          .getProject(), true, getFileChooserMode(), getParameter()
          .getFileType(), getParameter().usesFilter());
      ProjectTreePath[] projectTreePaths = chooser.getSelectedPaths();
      if ((projectTreePaths == null) || (projectTreePaths.length == 0)) {
        return files;
      }
      for (ProjectTreePath projectTreePath : projectTreePaths) {
        ClientProjectFile clientProjectFile = projectTreePath.getFile();
        String type;
        if (clientProjectFile.isDirectory()) {
          type = ProjectFileType.DIRECTORY_TYPE;
        }
        else {
          type = clientProjectFile.getType();
        }
        FileParameterValue file =
          new FileParameterValue(FileUtils.joinPath('/',
            projectTreePath.getPath()), type);
        files.add(file);
      }
      return files;
    }
    catch (ClientException e) {
      String errorMessage =
        "Ocorreu um erro ao abrir o dilogo de seleo de arquivos.";
      if (e.getLocalizedMessage() != null) {
        errorMessage += "\nDetalhes:\n";
        errorMessage += e.getLocalizedMessage();
      }
      StandardDialogs.showErrorDialog(getWindow(),
        "Erro ao abrir o dilogo de seleo de arquivo", errorMessage);
      return null;
    }
  }

  /**
   * Obtm o modo do {@link ProjectFileChooser} que ser utilizado para
   * solicitar os arquivos ao usurio.
   * 
   * @return .
   */
  protected int getFileChooserMode() {
    int mode;
    FileParameterMode parameterMode = getParameter().getMode();
    if (parameterMode.equals(FileParameterMode.REGULAR_FILE)) {
      mode = ProjectFileChooser.FILE_ONLY;
    }
    else if (parameterMode.equals(FileParameterMode.DIRECTORY)) {
      mode = ProjectFileChooser.DIRECTORY_ONLY;
    }
    else if (parameterMode.equals(FileParameterMode.DIRECTORY_AND_REGULAR_FILE)) {
      mode = ProjectFileChooser.FILE_AND_DIRECTORY;
    }
    else {
      String errorMessage =
        MessageFormat.format("O modo {0} no  vlido.", parameterMode);
      throw new IllegalStateException(errorMessage);
    }
    return mode;
  }
}

==> csbase-client-2.0.1-sources.jar: csbase/client/algorithms/parameters/InputFileListParameterView.java <==
/**
 * $Id: InputFileListParameterView.java 167814 2015-08-28 15:50:27Z analodi $
 */

package csbase.client.algorithms.parameters;

import java.awt.Window;
import java.text.MessageFormat;
import java.util.HashSet;
import java.util.Set;

import tecgraf.javautils.core.io.FileUtils;
import tecgraf.javautils.gui.StandardDialogs;
import csbase.client.desktop.DesktopFrame;
import csbase.client.kernel.ClientException;
import csbase.client.project.ProjectFileChooser;
import csbase.client.project.ProjectFileChooserOpen;
import csbase.client.project.ProjectTreePath;
import csbase.logic.ClientProjectFile;
import csbase.logic.ProjectFileType;
import csbase.logic.algorithms.parameters.FileParameterMode;
import csbase.logic.algorithms.parameters.InputFileListParameter;
import csbase.logic.algorithms.parameters.FileURLValue;

/**
 * Viso para {@link InputFileListParameter Parmetro do Tipo de Arquivo de
 * Entrada} com Seleo Mltipla.
 *
 * @author lmoreira
 */
public final class InputFileListParameterView extends FileListParameterView {

  /**
   * Cria uma viso em modo {@link ParameterView.Mode#CONFIGURATION}.
   *
   * @param window NO EST SENDO UTILIZADO. Existe somente para manter
   *        compatibilidade com o WebSintesi.
   * @param parameter O parmetro (No aceita {@code null}).
   *
   * @deprecated para manter compatibilidade com o WebSintesi
   */
  @Deprecated
  public InputFileListParameterView(Window window,
    InputFileListParameter parameter) {
    this(parameter, Mode.CONFIGURATION);
  }

  /**
   * Cria uma viso.
   *
   * @param parameter O parmetro (No aceita {@code null}).
   * @param mode Modo de visualizao. No aceita {@code null}, os possveis
   *        valores so: {@link ParameterView.Mode#CONFIGURATION} ou
   *        {@link ParameterView.Mode#REPORT}.
   */
  public InputFileListParameterView(InputFileListParameter parameter, Mode mode) {
    super(parameter, mode);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public InputFileListParameter getParameter() {
    return (InputFileListParameter) super.getParameter();
  }

  /**
   * Solicita os arquivos ao usurio.
   *
   * @return O conjunto de arquivos selecionados (Se o usurio cancelar a
   *         seleo, o conjunto estar vazio; se houver um erro durante a
   *         seleo, retorna {@code null}).
   */
  @Override
  protected Set<FileURLValue> askForFile() {
    try {
      Set<FileURLValue> files = new HashSet<FileURLValue>();
      ProjectFileChooser chooser =
        new ProjectFileChooserOpen(getWindow(), DesktopFrame.getInstance()
          .getProject(), true, getFileChooserMode(), getParameter()
          .getFileType(), getParameter().usesFilter());
      ProjectTreePath[] projectTreePaths = chooser.getSelectedPaths();
      if ((projectTreePaths == null) || (projectTreePaths.length == 0)) {
        return files;
      }
      for (ProjectTreePath projectTreePath : projectTreePaths) {
        ClientProjectFile clientProjectFile = projectTreePath.getFile();
        String type;
        if (clientProjectFile.isDirectory()) {
          type = ProjectFileType.DIRECTORY_TYPE;
        }
        else {
          type = clientProjectFile.getType();
        }
        FileURLValue file =
          new FileURLValue(FileUtils.joinPath('/', projectTreePath.getPath()), type);
        files.add(file);
      }
      return files;
    }
    catch (ClientException e) {
      String errorMessage =
        "Ocorreu um erro ao abrir o dilogo de seleo de arquivos.";
      if (e.getLocalizedMessage() != null) {
        errorMessage += "\nDetalhes:\n";
        errorMessage += e.getLocalizedMessage();
      }
      StandardDialogs.showErrorDialog(getWindow(),
        "Erro ao abrir o dilogo de seleo de arquivo", errorMessage);
      return null;
    }
  }

  /**
   * Obtm o modo do {@link ProjectFileChooser} que ser utilizado para
   * solicitar os arquivos ao usurio.
   *
   * @return .
   */
  protected int getFileChooserMode() {
    int mode;
    FileParameterMode parameterMode = getParameter().getMode();
    if (parameterMode.equals(FileParameterMode.REGULAR_FILE)) {
      mode = ProjectFileChooser.FILE_ONLY;
    }
    else if (parameterMode.equals(FileParameterMode.DIRECTORY)) {
      mode = ProjectFileChooser.DIRECTORY_ONLY;
    }
    else if (parameterMode.equals(FileParameterMode.DIRECTORY_AND_REGULAR_FILE)) {
      mode = ProjectFileChooser.FILE_AND_DIRECTORY;
    }
    else {
      String errorMessage =
        MessageFormat.format("O modo {0} no  vlido.", parameterMode);
      throw new IllegalStateException(errorMessage);
    }
    return mode;
  }
}
